@@ -1,15 +1,37 @@
 package Dist::Zilla::Plugin::Test::TrailingSpace;
 
-our $VERSION = '0.0.4';
+our $VERSION = '0.2.0';
 
 use 5.012;
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
-with 'Dist::Zilla::Role::PrereqSource';
+with qw/Dist::Zilla::Role::TextTemplate Dist::Zilla::Role::PrereqSource/;
 
 use namespace::autoclean;
 
+has filename_regex => (
+    is => 'ro',
+    isa => 'Str',
+    default => q/(?:\.(?:t|pm|pl|xs|c|h|txt|pod|PL)|README|Changes|TODO|LICENSE)\z/,
+);
+
+around add_file => sub {
+    my ($orig, $self, $file) = @_;
+
+    return $self->$orig(
+        Dist::Zilla::File::InMemory->new(
+            name => $file->name,
+            content => $self->fill_in_string($file->content,
+                {
+                    dist => \($self->zilla),
+                    filename_regex => $self->filename_regex,
+                }
+            )
+        )
+    );
+};
+
 # Register the release test prereq as a "develop requires"
 # so it will be listed in "dzil listdeps --author"
 sub register_prereqs {
@@ -41,7 +63,7 @@ in files.
 
 =head1 VERSION
 
-version 0.0.4
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -53,6 +75,21 @@ version 0.0.4
 
     $ dzil test --release
 
+=head1 DESCRIPTION
+
+This module tests adds a test for trailing whitespace in the distribution. It
+accepts the following parameters:
+
+=head2 filename_regex
+
+The regular expression for input to Test::TrailingSpace for matching the files
+to look for trailing space.
+
+Here is an example of how to override it:
+
+    [Test::TrailingSpace]
+    filename_regex = \.(?:pm|pod)\z
+
 =head1 SUBROUTINES/METHODS
 
 =head2 register_prereqs()
@@ -241,7 +278,7 @@ else
 my $finder = Test::TrailingSpace->new(
    {
        root => '.',
-       filename_regex => qr/(?:\.(?:t|pm|pl|xs|c|h|txt|pod|PL)|README|Changes|TODO|LICENSE)\z/,
+       filename_regex => qr#{{ $filename_regex }}#,
    },
 );
 
